@@ -10,7 +10,7 @@ using namespace Rcpp;
 class CoDcSbm : public IclModel
 {
 public:
-  CoDcSbm(const arma::sp_mat& xp,int Nri, int Nci,double alpha,arma::vec& cl,bool verb=false);
+  CoDcSbm(const arma::sp_mat& xp,int Nri, int Nci,S4 model,arma::vec& cl,bool verb=false);
   void set_cl(arma::vec clt);
   double icl_emiss(const List & obs_stats);
   double icl_emiss(const List & obs_stats,int oldcl,int newcl);
@@ -22,6 +22,7 @@ public:
   double delta_merge_correction(int k,int l,int obk,int obl,const List & old_stats);
   void merge_update(int k, int l);
   List get_obs_stats();
+  List get_obs_stats_cst();
 private:
   arma::sp_mat  x;
   // matrix of observed counts for each clusters
